@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown/reboot/suspend/hibernate the system
- * Copyright (C) 2010-2017 Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2019 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ class Gui : public QMainWindow, public Ui::Gui {
      bool            aWeeklyTimeWasSet;
      QPushButton     *minim;
      QTimer          *timer, *ti;
-     QDateTime       datetime, localDateTime, futureDateTime;
+     QDateTime       localDatetime, futureDateTime;
      QTime           elapsedTime, oldTime;
      QIcon           icon;
      QSystemTrayIcon *TIcon;
